#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ALL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ALL_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/all.hpp>

#endif
